@@ -27,6 +27,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 import argparse
 import sys
+import traceback
 
 # Check Python version
 if sys.version_info < (3, 6, 5):
@@ -39,7 +40,7 @@ else:
 
     # from .account import cmd_login
     from .analyze import cmd_analyze
-    from .parsers import nutrients, sort
+    from .parsers import day, nutrients, sort
     from .search import cmd_search
     from .utils.settings import TESTING
 
@@ -89,6 +90,10 @@ def build_argparser():
     # analyze_parser.add_argument("token", help="JSON web token to decode.", nargs="?")
     analyze_parser.set_defaults(func=cmd_analyze)  # , nargs="+")
 
+    # Day (analyze-day) subcommand
+    day_parser = subparsers.add_parser("day", help="use to sort foods by nutrient ID")
+    day_parser.set_defaults(func=day, nargs="+")
+
     # Nutrient subcommand
     nutrient_parser = subparsers.add_parser(
         "nt", help="list out nutrients and their info"
@@ -108,7 +113,13 @@ def main(argv=None):
     arg_parser = build_argparser()
     # Used for testing
     if TESTING and len(sys.argv) < 2:
-        sys.argv = ["./nutra", "sort", "789"]
+        sys.argv = [
+            "./nutra",
+            "day",
+            "~/.nutra/rocky.csv",
+            "~/.nutra/dog-rdas-18lbs.csv",
+        ]
+        # sys.argv = ["./nutra", "sort", "789"]
         # sys.argv = ["./nutra", "anl", "11233"]
         # sys.argv = ["./nutra", "nt"]
         # sys.argv = ["./nutra", "search", "grass", "fed", "beef"]
@@ -116,6 +127,8 @@ def main(argv=None):
         args, unknown = arg_parser.parse_known_args()
         args.func(args, unknown, arg_parser=arg_parser)
     except Exception as e:
-        # print_tb(e)
-        print("There was an unforseen error: ", e)
+        print("There was an unforseen error: ", repr(e))
+        if TESTING:
+            trace = "\n".join(traceback.format_tb(e.__traceback__))
+            print(trace)
         arg_parser.print_help()
