@@ -49,37 +49,69 @@ def cmd_analyze(args, unknown, arg_parser=None):
     res = response.json()["data"]
     analyses = res["analyses"]
     servings = res["servings"]
+    food_des = res["food_des"]
 
     # Get RDAs
     response = requests.get(f"{SERVER_HOST}/nutrients")
     rdas = response.json()["data"]
     rdas = {rda["id"]: rda for rda in rdas}
 
-    # print(json.dumps(rdas))
-    # print(json.dumps(analyses))
-    # print(len(analyses))
-    # print(rdas)
-
+    # --------------------------------------
+    # Food-by-food analysis (w/ servings)
+    # --------------------------------------
     for food in analyses:
+        food_id = food["food_id"]
+        food_name = food["long_desc"]
         print(
             "\n======================================\n"
-            f"==> {food['long_desc']} ({food['food_id']})\n"
+            f"==> {food_name} ({food_id})\n"
             "======================================\n",
         )
-        headers = ["nutrient", "amount", "units", "rda"]
+        print("\n=========================\nSERVINGS\n=========================\n")
+        ###############
+        # Serving table
+        headers = ["msre_id", "msre_desc", "grams"]
+        rows = [x for x in servings if x["food_id"] == food_id]
+        for r in rows:
+            r.pop("food_id")
+        print(tabulate(rows, headers="keys", tablefmt="presto"))
+
+        refuse = next(
+            (x for x in food_des if x["id"] == food_id and x["ref_desc"]), None
+        )
+        if refuse:
+            print("\n=========================\nREFUSE\n=========================\n")
+            print(refuse["ref_desc"])
+            print(f"    ({refuse['refuse']}%, by mass)")
+
+        print("\n=========================\nNUTRITION\n=========================\n")
+        ################
+        # Nutrient table
+        headers = ["id", "nutrient", "amount", "units", "rda"]
         rows = []
         food_nutes = {x["nutr_id"]: x for x in food["nutrients"]}
         for id, nute in food_nutes.items():
-            if not rdas[id]["rda"]:
-                continue
-
+            # Skip zero values
             amount = food_nutes[id]["nutr_val"]
             if not amount:
                 continue
-            rda_ratio = round(amount / rdas[id]["rda"] * 100, 1)
-            rows.append([nute["nutr_desc"], amount, rdas[id]["units"], f"{rda_ratio}%"])
-        print(tabulate(rows, headers=headers, tablefmt="orgtbl"))
-        # print(food["food_id"])
+
+            # Insert RDA % into row
+            if rdas[id]["rda"]:
+                rda_ratio = round(amount / rdas[id]["rda"] * 100, 1)
+                row = [
+                    id,
+                    nute["nutr_desc"],
+                    amount,
+                    rdas[id]["units"],
+                    f"{rda_ratio}%",
+                ]
+            else:
+                # print(rdas[id])
+                row = [id, nute["nutr_desc"], amount, rdas[id]["units"], None]
+
+            rows.append(row)
+        print(tabulate(rows, headers=headers, tablefmt="presto"))
 
 
 def parse_csv(file):
