@@ -1,12 +1,18 @@
+import os
+
+
 def git_sha():
     """ Gets the git revision, if it exists in cwd """
     try:
         from .__sha__ import __sha__
     except Exception as e1:
+        import subprocess
         from .settings import TESTING
+
         if not TESTING:
             print(repr(e1))
-        import subprocess
+        cwd = os.getcwd()
+        os.chdir(os.path.dirname(os.path.abspath(__file__)))
 
         try:
             __sha__ = (
@@ -18,6 +24,7 @@ def git_sha():
             print(repr(e2))
             __sha__ = None
 
+    os.chdir(cwd)
     return __sha__
 
 
